==> Tegra_Multimedia_API_R24.2.1_aarch64.tbz2: tegra_multimedia_api/argus/docs/doxygen/html/search/all_61.js <==
var searchData=
[
  ['acregion',['AcRegion',['../structArgus_1_1AcRegion.html',1,'Argus']]],
  ['acregion',['AcRegion',['../structArgus_1_1AcRegion.html#ac384535f03f0d5f2c792789766de6fb0',1,'Argus::AcRegion::AcRegion()'],['../structArgus_1_1AcRegion.html#ad79f34dcbb992babe1b17b2658acc5f7',1,'Argus::AcRegion::AcRegion(uint32_t _left, uint32_t _top, uint32_t _width, uint32_t _height, float _weight)']]],
  ['ae_5fantibanding_5fmode_5f50hz',['AE_ANTIBANDING_MODE_50HZ',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6ab67caeed6b761ee81c750b8999c4c3b7',1,'Argus']]],
  ['ae_5fantibanding_5fmode_5f60hz',['AE_ANTIBANDING_MODE_60HZ',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6a7caae47e009f43d50eeb38cbef32de13',1,'Argus']]],
  ['ae_5fantibanding_5fmode_5fauto',['AE_ANTIBANDING_MODE_AUTO',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6a3f392e7c6ce98bd0324c7d4b08d20ea4',1,'Argus']]],
  ['ae_5fantibanding_5fmode_5fcount',['AE_ANTIBANDING_MODE_COUNT',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6acb13399dd6782086812b4055ebfac89d',1,'Argus']]],
  ['ae_5fantibanding_5fmode_5foff',['AE_ANTIBANDING_MODE_OFF',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6adf3e1fef4d6d5e7ed51031a0e2dcc126',1,'Argus']]],
  ['ae_5fstate_5fconverged',['AE_STATE_CONVERGED',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0ad8773de94ac0af2321744154aefe3782',1,'Argus']]],
  ['ae_5fstate_5fcount',['AE_STATE_COUNT',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0a257465115283be4e043ba71416b08cb7',1,'Argus']]],
  ['ae_5fstate_5fflash_5frequired',['AE_STATE_FLASH_REQUIRED',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0ae2bcc7887fb4f2a3fde7f443d4b3b2d8',1,'Argus']]],
  ['ae_5fstate_5finactive',['AE_STATE_INACTIVE',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0a791f643941388c9124532802ac757efb',1,'Argus']]],
  ['ae_5fstate_5flocked',['AE_STATE_LOCKED',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0a9bae6a0a513afbf4af38f8d68dbeb901',1,'Argus']]],
  ['ae_5fstate_5fsearching',['AE_STATE_SEARCHING',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0a072997ea5c7809fdb749566e4559252b',1,'Argus']]],
  ['aeantibandingmode',['AeAntibandingMode',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6',1,'Argus']]],
  ['aestate',['AeState',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0',1,'Argus']]],
  ['argus',['Argus',['../namespaceArgus.html',1,'']]],
  ['argus_2eh',['Argus.h',['../Argus_8h.html',1,'']]],
  ['array2d',['Array2D',['../classArgus_1_1Array2D.html',1,'Argus']]],
  ['array2d',['Array2D',['../classArgus_1_1Array2D.html#a951a8a81048d0a2e221732fed4087729',1,'Argus::Array2D::Array2D()'],['../classArgus_1_1Array2D.html#ab40b4664dfcf6d858a732c60676463d3',1,'Argus::Array2D::Array2D(Size size)'],['../classArgus_1_1Array2D.html#a646ecbf4cbbd800801c865fa0b41e836',1,'Argus::Array2D::Array2D(Size size, const T &amp;value)'],['../classArgus_1_1Array2D.html#afba5aad8e211a848b824b4f4136bfd1b',1,'Argus::Array2D::Array2D(const Array2D&lt; T &gt; &amp;other)']]],
  ['autocontrolid',['AutoControlId',['../namespaceArgus.html#aa22f825d6820fd3ceab8f5849705db01',1,'Argus']]],
  ['awb_5fstate_5fconverged',['AWB_STATE_CONVERGED',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305dae41c75aa5dade149edc920b0bd2bb5d1',1,'Argus']]],
  ['awb_5fstate_5fcount',['AWB_STATE_COUNT',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305da0db38b6b4abeb3620903d080468c186b',1,'Argus']]],
  ['awb_5fstate_5finactive',['AWB_STATE_INACTIVE',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305dacff3e62f1f73f2fbe7d9aeb53522495e',1,'Argus']]],
  ['awb_5fstate_5flocked',['AWB_STATE_LOCKED',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305da6ec1e7fb73ec5454369e63b3fcc02e49',1,'Argus']]],
  ['awb_5fstate_5fsearching',['AWB_STATE_SEARCHING',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305dae0cfb2f8ac0c3a15021db2aa5dd0f199',1,'Argus']]],
  ['awbstate',['AwbState',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305d',1,'Argus']]],
  ['ext',['Ext',['../namespaceArgus_1_1Ext.html',1,'Argus']]]
];

==> Tegra_Multimedia_API_R27.1.0_aarch64.tbz2: tegra_multimedia_api/argus/docs/doxygen/html/search/all_61.js <==
var searchData=
[
  ['acregion',['AcRegion',['../classArgus_1_1AcRegion.html',1,'Argus']]],
  ['acregion',['AcRegion',['../classArgus_1_1AcRegion.html#ac384535f03f0d5f2c792789766de6fb0',1,'Argus::AcRegion::AcRegion()'],['../classArgus_1_1AcRegion.html#a5cfa0aa1c6d33fdad6050f57a57d03f9',1,'Argus::AcRegion::AcRegion(uint32_t _left, uint32_t _top, uint32_t _right, uint32_t _bottom, float _weight)']]],
  ['ae_5fantibanding_5fmode_5f50hz',['AE_ANTIBANDING_MODE_50HZ',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6ab67caeed6b761ee81c750b8999c4c3b7',1,'Argus']]],
  ['ae_5fantibanding_5fmode_5f60hz',['AE_ANTIBANDING_MODE_60HZ',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6a7caae47e009f43d50eeb38cbef32de13',1,'Argus']]],
  ['ae_5fantibanding_5fmode_5fauto',['AE_ANTIBANDING_MODE_AUTO',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6a3f392e7c6ce98bd0324c7d4b08d20ea4',1,'Argus']]],
  ['ae_5fantibanding_5fmode_5fcount',['AE_ANTIBANDING_MODE_COUNT',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6acb13399dd6782086812b4055ebfac89d',1,'Argus']]],
  ['ae_5fantibanding_5fmode_5foff',['AE_ANTIBANDING_MODE_OFF',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6adf3e1fef4d6d5e7ed51031a0e2dcc126',1,'Argus']]],
  ['ae_5fstate_5fconverged',['AE_STATE_CONVERGED',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0ad8773de94ac0af2321744154aefe3782',1,'Argus']]],
  ['ae_5fstate_5fcount',['AE_STATE_COUNT',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0a257465115283be4e043ba71416b08cb7',1,'Argus']]],
  ['ae_5fstate_5fflash_5frequired',['AE_STATE_FLASH_REQUIRED',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0ae2bcc7887fb4f2a3fde7f443d4b3b2d8',1,'Argus']]],
  ['ae_5fstate_5finactive',['AE_STATE_INACTIVE',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0a791f643941388c9124532802ac757efb',1,'Argus']]],
  ['ae_5fstate_5flocked',['AE_STATE_LOCKED',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0a9bae6a0a513afbf4af38f8d68dbeb901',1,'Argus']]],
  ['ae_5fstate_5fsearching',['AE_STATE_SEARCHING',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0a072997ea5c7809fdb749566e4559252b',1,'Argus']]],
  ['aeantibandingmode',['AeAntibandingMode',['../namespaceArgus.html#ab21b2fd07e4a236c0340b73ce3ed72a6',1,'Argus']]],
  ['aestate',['AeState',['../namespaceArgus.html#afd2a6010ffbfe6b1e60d3170e11cf4e0',1,'Argus']]],
  ['area',['area',['../classArgus_1_1Size2D.html#a2cf8d97c8d5c55005669751735988568',1,'Argus::Size2D::area()'],['../classArgus_1_1Rectangle.html#a40b68104a2f3cf969dff0b7b26a8faf2',1,'Argus::Rectangle::area()']]],
  ['argus',['Argus',['../namespaceArgus.html',1,'']]],
  ['argus_2eh',['Argus.h',['../Argus_8h.html',1,'']]],
  ['array2d',['Array2D',['../classArgus_1_1Array2D.html#a951a8a81048d0a2e221732fed4087729',1,'Argus::Array2D::Array2D()'],['../classArgus_1_1Array2D.html#a5176c6edb2a10014e2ec30659160669f',1,'Argus::Array2D::Array2D(const Size2D&lt; uint32_t &gt; &amp;size)'],['../classArgus_1_1Array2D.html#ac2ab97e9bcbb931e374f21bf19a50d98',1,'Argus::Array2D::Array2D(const Size2D&lt; uint32_t &gt; &amp;size, const T &amp;value)'],['../classArgus_1_1Array2D.html#afba5aad8e211a848b824b4f4136bfd1b',1,'Argus::Array2D::Array2D(const Array2D&lt; T &gt; &amp;other)']]],
  ['array2d',['Array2D',['../classArgus_1_1Array2D.html',1,'Argus']]],
  ['autocontrolid',['AutoControlId',['../namespaceArgus.html#aa22f825d6820fd3ceab8f5849705db01',1,'Argus']]],
  ['awb_5fstate_5fconverged',['AWB_STATE_CONVERGED',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305dae41c75aa5dade149edc920b0bd2bb5d1',1,'Argus']]],
  ['awb_5fstate_5fcount',['AWB_STATE_COUNT',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305da0db38b6b4abeb3620903d080468c186b',1,'Argus']]],
  ['awb_5fstate_5finactive',['AWB_STATE_INACTIVE',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305dacff3e62f1f73f2fbe7d9aeb53522495e',1,'Argus']]],
  ['awb_5fstate_5flocked',['AWB_STATE_LOCKED',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305da6ec1e7fb73ec5454369e63b3fcc02e49',1,'Argus']]],
  ['awb_5fstate_5fsearching',['AWB_STATE_SEARCHING',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305dae0cfb2f8ac0c3a15021db2aa5dd0f199',1,'Argus']]],
  ['awbstate',['AwbState',['../namespaceArgus.html#a37e915271fae3e7b6e72c6743df0305d',1,'Argus']]],
  ['ext',['Ext',['../namespaceArgus_1_1Ext.html',1,'Argus']]]
];
